export default function seoMeta(options, nuxtContext = {}) {
  const imageUrl = options.image || options.defaultImage;
  const url = options.url || options.defaultUrl;
  const description = options.description || options.defaultDescription;
  const baseMeta = [
    {name: "title", content: options.title},
    {name: "description", content: description},
    {name: "image", content: imageUrl},
    {name: "keywords", content: options.keywords || description}
  ];
  const ogMeta = [
    {property: "og:title", content: options.title},
    {property: "og:description", content: description},
    {property: "og:type", content: "website"},
    {property: "og:url", content: url},
    {property: "og:image", content: imageUrl},
    {property: "og:locale", content: options.locale},
    {property: "og:site_name", content: options.siteName}
  ];
  const twitterMeta = [
    {name: "twitter:card", content: "summary_large_image"},
    {name: "twitter:site", content: url},
    {name: "twitter:creator", content: options.twitterUser},
    {name: "twitter:title", content: options.title},
    {name: "twitter:description", content: description},
    {name: "twitter:image", content: imageUrl}
  ];
  const metaTags = [baseMeta];
  if (!options.ignoreTwitter)
    metaTags.push(twitterMeta);
  if (!options.ignoreOG)
    metaTags.push(ogMeta);
  const tags = metaTags.flat();
  const normalizedMetas = tags.reduce((memo, tag) => {
    if (!tag.content)
      return memo;
    if (tag.name) {
      memo.push({
        hid: tag.name,
        name: tag.name,
        content: tag.content
      });
    } else if (tag.property) {
      memo.push({
        hid: tag.property,
        property: tag.property,
        content: tag.content
      });
    }
    return memo;
  }, []);
  if (nuxtContext.app) {
    const {app: nuxtApp} = nuxtContext;
    if (nuxtApp.head && typeof nuxtApp.head !== "function") {
      nuxtApp.head.meta = [
        ...nuxtApp.head.meta || [],
        ...Object.values({
          ...keyBy(nuxtApp.head.meta || [], "hid"),
          ...keyBy(normalizedMetas, "hid")
        })
      ];
    }
  }
  return normalizedMetas;
}
function keyBy(arr, key) {
  const obj = {};
  for (const val of arr) {
    obj[val[key]] = val;
  }
  return obj;
}
